Info: Checks that Turkish ID number is correct or not.
Params: id is TC ID, skipRealCitizen is a key that controls not to create a real citizen ID. If it is true, ID will start 0, it is not correct on real life, notPrint enables / dsiables console log. If true, log will printed.
Params: skipRealCitizen is a key that controls not to create a real citizen ID. If it is true, ID will start 0, it is not correct on real life, computeFake is a key that controls compute Fake TC ID or returns a logger.printLog ready value.
Info: Validate that Foreign ID number given by Turkish authorities with given credentials from Web API.
Params: id is TC ID, name is user name, surname is user surname, birthDay is user birth day, birthMonth is user birth month, birthYear is user birth year, skipRealCitizen is a key that controls not to create a real citizen ID. If it is true, ID will start 0, it is not correct on real life.
Info: Validate that Turkish ID number with given credentials from Web API.
Params: id is TC ID, name is user name, surname is user surname, birthYear is user birth year, skipRealCitizen is a key that controls not to create a real citizen ID. If it is true, ID will start 0, it is not correct on real life.
Info: Validates Person and ID Card with given credentials from Web API.
Params: id is TC ID, name is user name, surname is user surname, noSurname is person have surname or not, birthDay is user birth day, noBirthDay is person have birth day or not, birthMonth is user birth month, noBirthMonth is person have birth month or not, birthYear is user birth year, oldWalletSerial is old wallet serial code, oldWalletNo is old wallet number, newidCardSerial is new TC ID Card serial number, skipRealCitizen is a key that controls not to create a real citizen ID. If it is true, ID will start 0, it is not correct on real life.
Returns: boolean.
Notes: Returns always 'false' due to response from Web API. Service may have been stopped from authorities after Turkish people info leak.